==> generator-ng-poly-0.11.5.tgz: package/generators/genBase/index.js <==
'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

require('babel-polyfill');

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _pify = require('pify');

var _pify2 = _interopRequireDefault(_pify);

var _package = require('../../package.json');

var _package2 = _interopRequireDefault(_package);

var _recursiveReaddir = require('recursive-readdir');

var _recursiveReaddir2 = _interopRequireDefault(_recursiveReaddir);

var _updateNotifier = require('update-notifier');

var _updateNotifier2 = _interopRequireDefault(_updateNotifier);

var _utils = require('../utils');

var _utils2 = _interopRequireDefault(_utils);

var _yeomanGenerator = require('yeoman-generator');

var _yeomanGenerator2 = _interopRequireDefault(_yeomanGenerator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = _yeomanGenerator2.default.Base.extend({
  constructor: function constructor() {
    _yeomanGenerator2.default.Base.apply(this, arguments);
    this.name = arguments['0'][0];
  },
  askForModuleName: function askForModuleName(params) {
    var _this = this;

    var config = this.config,
        done = this.async(),
        name = this.name,
        options = this.options;

    var notifier = (0, _updateNotifier2.default)({
      packageName: _package2.default.name,
      packageVersion: _package2.default.version
    });

    // notifiy user about update, if there is an update
    notifier.notify();

    this.prompt([{
      type: 'list',
      name: 'module',
      store: true,
      message: 'Which module is this for?',
      default: config.get('lastUsedModule'),
      when: function when() {
        return !(options && options.module);
      },
      choices: function choices() {
        var choicesDone, directory, files;
        return regeneratorRuntime.async(function choices$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                choicesDone = this.async();
                _context.next = 3;
                return regeneratorRuntime.awrap(_utils2.default.getAppDir());

              case 3:
                directory = _context.sent;
                _context.next = 6;
                return regeneratorRuntime.awrap((0, _pify2.default)(_recursiveReaddir2.default)(directory));

              case 6:
                files = _context.sent;
                _context.next = 9;
                return regeneratorRuntime.awrap(_utils2.default.moduleFilter(files));

              case 9:
                _context.t0 = _context.sent;
                choicesDone(_context.t0);

              case 11:
              case 'end':
                return _context.stop();
            }
          }
        }, null, this);
      }
    }, {
      name: 'url',
      message: 'What\'s the URL for this route?',
      default: function _default() {
        // if child state return child portion as url
        if (name.indexOf('.') > -1) {
          return '/' + _utils2.default.hyphenName(name.split('.')[1]);
        }
        return '/' + _utils2.default.hyphenName(name);
      },
      when: function when() {
        return params && params.url && !config.get('ngRoute') && !(options && options.url);
      }
    }, {
      name: 'templateUrl',
      message: 'What\'s the templateURL for this route?',
      default: function _default(answers) {
        var defaultDone, module, normalizeModulePath;
        return regeneratorRuntime.async(function _default$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                defaultDone = this.async();
                module = answers.module || options.module;
                _context2.next = 4;
                return regeneratorRuntime.awrap(_utils2.default.normalizeModulePath(module));

              case 4:
                normalizeModulePath = _context2.sent;

                defaultDone(normalizeModulePath + '/' + (options.structure === 'module-type' || config.get('structure') === 'module-type' ? 'views/' : '') + _utils2.default.hyphenName(name.replace('.', '-')) + '.tpl.html');

              case 6:
              case 'end':
                return _context2.stop();
            }
          }
        }, null, this);
      },

      when: function when() {
        return params && params.templateUrl && !(options && options['template-url']);
      }
    }], function (props) {
      _this.module = props.module || options.module;
      _this.url = props.url || options.url || name;
      _this.templateUrl = props.templateUrl || options['template-url'];

      // if moduleName ends with a slash remove it
      if (_this.module.charAt(_this.module.length - 1) === '/' || _this.module.charAt(_this.module.length - 1) === '\\') {
        _this.module = _this.module.slice(0, _this.module.length - 1);
      }

      // prepend slash if missing
      if (_this.url && _this.url.charAt(0) !== '/' && _this.url.charAt(0) !== '\\') {
        _this.url = '/' + _this.url;
      }

      // convert backslashes to forwardslashes for Windows
      if (_this.templateUrl) {
        _this.templateUrl = _this.templateUrl.replace('\\', '/');
      }

      // append .tpl.html if not existing
      if (!/[.]tpl[.]html$/.test(_this.templateUrl)) {
        _this.templateUrl = _this.templateUrl + '.tpl.html';
      }

      done();
    });
  },
  getConfig: function getConfig() {
    var config, modules;
    return regeneratorRuntime.async(function getConfig$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            config = undefined, modules = undefined;
            _context3.t0 = this.name;
            _context3.t1 = this.options.markup || this.config.get('markup');
            _context3.t2 = this.options['app-script'] || this.config.get('appScript');
            _context3.t3 = this.options.structure || this.config.get('structure');
            _context3.t4 = this.config.get('controllerAs');
            _context3.t5 = this.options['directive-template-url'] !== undefined && this.options['directive-template-url'] !== null ? this.options['directive-template-url'] : this.config.get('directiveTemplateUrl');
            _context3.t6 = this.options['skip-controller'] !== undefined && this.options['skip-controller'] !== null ? this.options['skip-controller'] : this.config.get('skipController');
            _context3.t7 = this.options['test-script'] || this.config.get('testScript');
            _context3.t8 = this.config.get('testFramework');
            _context3.t9 = this.config.get('e2eTestFramework');
            _context3.t10 = this.options.style || this.config.get('style');
            _context3.t11 = this.config.get('ngRoute');
            _context3.next = 15;
            return regeneratorRuntime.awrap(_utils2.default.getAppDir());

          case 15:
            _context3.t12 = _context3.sent;
            _context3.next = 18;
            return regeneratorRuntime.awrap(_utils2.default.getAppName());

          case 18:
            _context3.t13 = _context3.sent;
            _context3.next = 21;
            return regeneratorRuntime.awrap(_utils2.default.getUnitTestDir());

          case 21:
            _context3.t14 = _context3.sent;
            _context3.t15 = _utils2.default.ctrlName(this.name);
            _context3.t16 = _utils2.default.humanName(this.name);
            _context3.t17 = _utils2.default.hyphenName(this.name);
            _context3.t18 = _utils2.default.lowerCamel(this.name);
            _context3.t19 = _utils2.default.upperCamel(this.name);
            config = {
              name: _context3.t0,
              markup: _context3.t1,
              appScript: _context3.t2,
              structure: _context3.t3,
              controllerAs: _context3.t4,
              directiveTemplateUrl: _context3.t5,
              skipController: _context3.t6,
              testScript: _context3.t7,
              testFramework: _context3.t8,
              e2eTestFramework: _context3.t9,
              style: _context3.t10,
              ngRoute: _context3.t11,
              appDir: _context3.t12,
              appName: _context3.t13,
              testDir: _context3.t14,
              ctrlName: _context3.t15,
              humanName: _context3.t16,
              hyphenName: _context3.t17,
              lowerCamel: _context3.t18,
              upperCamel: _context3.t19
            };

            if (this.module) {
              _context3.next = 30;
              break;
            }

            return _context3.abrupt('return', config);

          case 30:
            _context3.next = 32;
            return regeneratorRuntime.awrap(_utils2.default.extractModuleNames(this.module));

          case 32:
            modules = _context3.sent;

            config.moduleName = _utils2.default.lowerCamel(modules[0]);
            config.parentModuleName = _utils2.default.lowerCamel(modules[1]);

            _context3.next = 37;
            return regeneratorRuntime.awrap(_utils2.default.normalizeModulePath(this.module));

          case 37:
            config.modulePath = _context3.sent;

            // create reference path to typings/tsd.d.ts from generated file
            if (config.appScript === 'ts') {
              // relative path between module path
              config.referencePath = _path2.default.relative(config.modulePath, _path2.default.dirname(this.config.path));
              // replace Windows path separators with Unix
              config.referencePath = config.referencePath.replace('\\', '/');
              config.referencePath = '../' + config.referencePath + '/typings/tsd.d.ts';
              // if module/type structure we need to go up one more folder
              if (config.structure === 'module-type' && !this.isModule) {
                config.referencePath = '../' + config.referencePath;
              }
            }

            return _context3.abrupt('return', config);

          case 40:
          case 'end':
            return _context3.stop();
        }
      }
    }, null, this);
  },
  copyFile: function copyFile(type, component, dest, context) {
    var pluralComponent, fileName, src;
    return regeneratorRuntime.async(function copyFile$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            pluralComponent = component === 'factory' ? 'factories' : component + 's', fileName = undefined, src = undefined;

            if ((typeof dest === 'undefined' ? 'undefined' : _typeof(dest)) === 'object') {
              context = dest;
              dest = null;
            }

            _context4.t0 = context;

            if (_context4.t0) {
              _context4.next = 7;
              break;
            }

            _context4.next = 6;
            return regeneratorRuntime.awrap(this.getConfig());

          case 6:
            _context4.t0 = _context4.sent;

          case 7:
            context = _context4.t0;

            if (!dest) {
              // test or app directory?
              dest = type === 'unit' ? context.testDir : context.appDir;
              // append module path and type (if using module-type)
              dest = _path2.default.join(dest, context.modulePath, component !== 'module' && context.structure === 'module-type' ? pluralComponent : '');

              // create file name
              fileName = context.hyphenName + '-' + component;
              if (type === 'markup') {
                fileName += '.tpl.' + context.markup;
              }
              if (type === 'src') {
                fileName += '.' + context.appScript;
              }
              if (type === 'unit') {
                fileName += '_test.' + context.testScript;
              }
              // style types ALWAYS send a dest

              // append file name to dest
              dest = _path2.default.join(dest, fileName);
            }

            if (type === 'markup') {
              src = '_' + component + '.' + context.markup;
            }
            if (type === 'src') {
              src = '_' + component + '.' + context.appScript;
            }
            if (type === 'style') {
              src = component + '.' + context.style;
            }
            if (type === 'unit') {
              src = '_spec.' + context.testScript;
            }

            this.copySimpleFile(src, dest, context);

          case 14:
          case 'end':
            return _context4.stop();
        }
      }
    }, null, this);
  },
  copySimpleFile: function copySimpleFile(src, dest, context) {
    context = context || this.context;
    // remove underscore from templated file names
    dest = dest || src.replace(/_/g, '');

    this.fs.copyTpl(this.templatePath(src), this.destinationPath(dest), context);
  },
  copyMarkupFile: function copyMarkupFile(component, dest, context) {
    return this.copyFile('markup', component, dest, context);
  },
  copySrcFile: function copySrcFile(component, dest, context) {
    return this.copyFile('src', component, dest, context);
  },
  copyStyleFile: function copyStyleFile(component, dest, context) {
    return this.copyFile('style', component, dest, context);
  },
  copyUnitTest: function copyUnitTest(component, dest, context) {
    return this.copyFile('unit', component, dest, context);
  },
  copyE2e: function copyE2e(context) {
    var testScript = context.testScript === 'ts' ? 'js' : context.testScript,
        e2eFile = _path2.default.join('e2e', context.hyphenName, context.hyphenName);

    this.copySimpleFile('page.po.' + testScript, e2eFile + '.po.' + testScript, context);
    this.copySimpleFile('page_test.' + testScript, e2eFile + '_test.' + testScript, context);
  }
});

==> generator-ng-poly-0.12.2.tgz: package/generators/genBase/index.js <==
'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

require('babel-polyfill');

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _pify = require('pify');

var _pify2 = _interopRequireDefault(_pify);

var _package = require('../../package.json');

var _package2 = _interopRequireDefault(_package);

var _recursiveReaddir = require('recursive-readdir');

var _recursiveReaddir2 = _interopRequireDefault(_recursiveReaddir);

var _updateNotifier = require('update-notifier');

var _updateNotifier2 = _interopRequireDefault(_updateNotifier);

var _utils = require('../utils');

var _utils2 = _interopRequireDefault(_utils);

var _yeomanGenerator = require('yeoman-generator');

var _yeomanGenerator2 = _interopRequireDefault(_yeomanGenerator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = _yeomanGenerator2.default.Base.extend({
  constructor: function constructor() {
    _yeomanGenerator2.default.Base.apply(this, arguments);
    this.name = arguments['0'][0];
  },
  askForModuleName: function askForModuleName(params) {
    var _this = this;

    var config = this.config,
        done = this.async(),
        name = this.name,
        options = this.options;

    var notifier = (0, _updateNotifier2.default)({
      packageName: _package2.default.name,
      packageVersion: _package2.default.version
    });

    // notifiy user about update, if there is an update
    notifier.notify();

    this.prompt([{
      type: 'list',
      name: 'module',
      store: true,
      message: 'Which module is this for?',
      default: config.get('lastUsedModule'),
      when: function when() {
        return !(options && options.module);
      },
      choices: function choices() {
        var choicesDone, directory, files;
        return regeneratorRuntime.async(function choices$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                choicesDone = this.async();
                _context.next = 3;
                return regeneratorRuntime.awrap(_utils2.default.getAppDir());

              case 3:
                directory = _context.sent;
                _context.next = 6;
                return regeneratorRuntime.awrap((0, _pify2.default)(_recursiveReaddir2.default)(directory));

              case 6:
                files = _context.sent;
                _context.next = 9;
                return regeneratorRuntime.awrap(_utils2.default.moduleFilter(files));

              case 9:
                _context.t0 = _context.sent;
                choicesDone(_context.t0);

              case 11:
              case 'end':
                return _context.stop();
            }
          }
        }, null, this);
      }
    }, {
      name: 'url',
      message: 'What\'s the URL for this route?',
      default: function _default() {
        // if child state return child portion as url
        if (name.indexOf('.') > -1) {
          return '/' + _utils2.default.hyphenName(name.split('.')[1]);
        }
        return '/' + _utils2.default.hyphenName(name);
      },
      when: function when() {
        return params && params.url && !config.get('ngRoute') && !(options && options.url);
      }
    }, {
      name: 'templateUrl',
      message: 'What\'s the templateURL for this route?',
      default: function _default(answers) {
        var defaultDone, module, normalizeModulePath;
        return regeneratorRuntime.async(function _default$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                defaultDone = this.async();
                module = answers.module || options.module;
                _context2.next = 4;
                return regeneratorRuntime.awrap(_utils2.default.normalizeModulePath(module));

              case 4:
                normalizeModulePath = _context2.sent;


                defaultDone(normalizeModulePath + '/' + (options.structure === 'module-type' || config.get('structure') === 'module-type' ? 'views/' : '') + _utils2.default.hyphenName(name.replace('.', '-')) + '.tpl.html');

              case 6:
              case 'end':
                return _context2.stop();
            }
          }
        }, null, this);
      },

      when: function when() {
        return params && params.templateUrl && !(options && options['template-url']);
      }
    }], function (props) {
      _this.module = props.module || options.module;
      _this.url = props.url || options.url || name;
      _this.templateUrl = props.templateUrl || options['template-url'];

      // if moduleName ends with a slash remove it
      if (_this.module.charAt(_this.module.length - 1) === '/' || _this.module.charAt(_this.module.length - 1) === '\\') {
        _this.module = _this.module.slice(0, _this.module.length - 1);
      }

      // prepend slash if missing
      if (_this.url && _this.url.charAt(0) !== '/' && _this.url.charAt(0) !== '\\') {
        _this.url = '/' + _this.url;
      }

      // convert backslashes to forwardslashes for Windows
      if (_this.templateUrl) {
        _this.templateUrl = _this.templateUrl.replace('\\', '/');
      }

      // append .tpl.html if not existing
      if (!/[.]tpl[.]html$/.test(_this.templateUrl)) {
        _this.templateUrl = _this.templateUrl + '.tpl.html';
      }

      done();
    });
  },
  getConfig: function getConfig() {
    var config, modules;
    return regeneratorRuntime.async(function getConfig$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            config = void 0, modules = void 0;
            _context3.t0 = this.name;
            _context3.t1 = this.options.markup || this.config.get('markup');
            _context3.t2 = this.options['app-script'] || this.config.get('appScript');
            _context3.t3 = this.options.structure || this.config.get('structure');
            _context3.t4 = this.config.get('controllerAs');
            _context3.t5 = this.options['directive-template-url'] !== undefined && this.options['directive-template-url'] !== null ? this.options['directive-template-url'] : this.config.get('directiveTemplateUrl');
            _context3.t6 = this.options['skip-controller'] !== undefined && this.options['skip-controller'] !== null ? this.options['skip-controller'] : this.config.get('skipController');
            _context3.t7 = this.options['test-script'] || this.config.get('testScript');
            _context3.t8 = this.config.get('testFramework');
            _context3.t9 = this.config.get('e2eTestFramework');
            _context3.t10 = this.options.style || this.config.get('style');
            _context3.t11 = this.config.get('ngRoute');
            _context3.next = 15;
            return regeneratorRuntime.awrap(_utils2.default.getAppDir());

          case 15:
            _context3.t12 = _context3.sent;
            _context3.next = 18;
            return regeneratorRuntime.awrap(_utils2.default.getAppName());

          case 18:
            _context3.t13 = _context3.sent;
            _context3.next = 21;
            return regeneratorRuntime.awrap(_utils2.default.getUnitTestDir());

          case 21:
            _context3.t14 = _context3.sent;
            _context3.t15 = _utils2.default.ctrlName(this.name);
            _context3.t16 = _utils2.default.humanName(this.name);
            _context3.t17 = _utils2.default.hyphenName(this.name);
            _context3.t18 = _utils2.default.lowerCamel(this.name);
            _context3.t19 = _utils2.default.upperCamel(this.name);
            config = {
              name: _context3.t0,
              markup: _context3.t1,
              appScript: _context3.t2,
              structure: _context3.t3,
              controllerAs: _context3.t4,
              directiveTemplateUrl: _context3.t5,
              skipController: _context3.t6,
              testScript: _context3.t7,
              testFramework: _context3.t8,
              e2eTestFramework: _context3.t9,
              style: _context3.t10,
              ngRoute: _context3.t11,
              appDir: _context3.t12,
              appName: _context3.t13,
              testDir: _context3.t14,
              ctrlName: _context3.t15,
              humanName: _context3.t16,
              hyphenName: _context3.t17,
              lowerCamel: _context3.t18,
              upperCamel: _context3.t19
            };

            if (this.module) {
              _context3.next = 30;
              break;
            }

            return _context3.abrupt('return', config);

          case 30:
            _context3.next = 32;
            return regeneratorRuntime.awrap(_utils2.default.extractModuleNames(this.module));

          case 32:
            modules = _context3.sent;

            config.moduleName = _utils2.default.lowerCamel(modules[0]);
            config.parentModuleName = _utils2.default.lowerCamel(modules[1]);

            _context3.next = 37;
            return regeneratorRuntime.awrap(_utils2.default.normalizeModulePath(this.module));

          case 37:
            config.modulePath = _context3.sent;


            // create reference path to typings/tsd.d.ts from generated file
            if (config.appScript === 'ts') {
              // relative path between module path
              config.referencePath = _path2.default.relative(config.modulePath, _path2.default.dirname(this.config.path));
              // replace Windows path separators with Unix
              config.referencePath = config.referencePath.replace('\\', '/');
              config.referencePath = '../' + config.referencePath + '/typings/tsd.d.ts';
              // if module/type structure we need to go up one more folder
              if (config.structure === 'module-type' && !this.isModule) {
                config.referencePath = '../' + config.referencePath;
              }
            }

            return _context3.abrupt('return', config);

          case 40:
          case 'end':
            return _context3.stop();
        }
      }
    }, null, this);
  },
  copyFile: function copyFile(type, component, dest, context) {
    var pluralComponent, fileName, src;
    return regeneratorRuntime.async(function copyFile$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            pluralComponent = component === 'factory' ? 'factories' : component + 's', fileName = void 0, src = void 0;


            if ((typeof dest === 'undefined' ? 'undefined' : _typeof(dest)) === 'object') {
              context = dest;
              dest = null;
            }

            _context4.t0 = context;

            if (_context4.t0) {
              _context4.next = 7;
              break;
            }

            _context4.next = 6;
            return regeneratorRuntime.awrap(this.getConfig());

          case 6:
            _context4.t0 = _context4.sent;

          case 7:
            context = _context4.t0;


            if (!dest) {
              // test or app directory?
              dest = type === 'unit' ? context.testDir : context.appDir;
              // append module path and type (if using module-type)
              dest = _path2.default.join(dest, context.modulePath, component !== 'module' && context.structure === 'module-type' ? pluralComponent : '');

              // create file name
              fileName = context.hyphenName + '-' + component;
              if (type === 'markup') {
                fileName += '.tpl.' + context.markup;
              }
              if (type === 'src') {
                fileName += '.' + context.appScript;
              }
              if (type === 'unit') {
                fileName += '_test.' + context.testScript;
              }
              // style types ALWAYS send a dest

              // append file name to dest
              dest = _path2.default.join(dest, fileName);
            }

            if (type === 'markup') {
              src = '_' + component + '.' + context.markup;
            }
            if (type === 'src') {
              src = '_' + component + '.' + context.appScript;
            }
            if (type === 'style') {
              src = component + '.' + context.style;
            }
            if (type === 'unit') {
              src = '_spec.' + context.testScript;
            }

            this.copySimpleFile(src, dest, context);

          case 14:
          case 'end':
            return _context4.stop();
        }
      }
    }, null, this);
  },
  copySimpleFile: function copySimpleFile(src, dest, context) {
    context = context || this.context;
    // remove underscore from templated file names
    dest = dest || src.replace(/_/g, '');

    this.fs.copyTpl(this.templatePath(src), this.destinationPath(dest), context);
  },
  copyMarkupFile: function copyMarkupFile(component, dest, context) {
    return this.copyFile('markup', component, dest, context);
  },
  copySrcFile: function copySrcFile(component, dest, context) {
    return this.copyFile('src', component, dest, context);
  },
  copyStyleFile: function copyStyleFile(component, dest, context) {
    return this.copyFile('style', component, dest, context);
  },
  copyUnitTest: function copyUnitTest(component, dest, context) {
    return this.copyFile('unit', component, dest, context);
  },
  copyE2e: function copyE2e(context) {
    var testScript = context.testScript === 'ts' ? 'js' : context.testScript,
        e2eFile = _path2.default.join('e2e', context.hyphenName, context.hyphenName);

    this.copySimpleFile('page.po.' + testScript, e2eFile + '.po.' + testScript, context);
    this.copySimpleFile('page_test.' + testScript, e2eFile + '_test.' + testScript, context);
  }
});
